@@ -368,17 +368,6 @@ void Wizard::checkMltComponents()
             delete consumer;
         }
 
-        // DV module
-        QTreeWidgetItem *dvItem = new QTreeWidgetItem(m_mltCheck.programList, QStringList() << QString() << i18n("DV module (libdv)"));
-        dvItem->setData(1, Qt::UserRole, i18n("Required to work with dv files if avformat module is not installed"));
-        dvItem->setSizeHint(0, itemSize);
-        if (!producersItemList.contains("libdv")) {
-            dvItem->setIcon(0, m_badIcon);
-        }
-        else {
-            dvItem->setIcon(0, m_okIcon);
-        }
-
         // Image module
         QTreeWidgetItem *imageItem = new QTreeWidgetItem(m_mltCheck.programList, QStringList() << QString() << i18n("QImage module"));
         imageItem->setData(1, Qt::UserRole, i18n("Required to work with images"));
@@ -584,7 +573,11 @@ void Wizard::installExtraMimes(const QString &baseName, const QStringList &globs
             if (!extensions.contains(glob)) extensions << glob;
         }
         //qDebug() << "EXTS: " << extensions;
-        QString packageFileName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/mime/") + "packages/" + mimefile + ".xml";
+        QDir mimeDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/mime/packages/"));
+        if (!mimeDir.exists()) {
+            mimeDir.mkpath(".");
+        }
+        QString packageFileName = mimeDir.absoluteFilePath(mimefile + ".xml");
         //qDebug() << "INSTALLING NEW MIME TO: " << packageFileName;
         QFile packageFile(packageFileName);
         if (!packageFile.open(QIODevice::WriteOnly)) {
